%global _pyinclude %{_includedir}/python%{python3_version}

%global _sip_api_major 12
%global _sip_api_minor 7
%global _sip_api %{_sip_api_major}.%{_sip_api_minor}

Summary:  SIP - Python/C++ Bindings Generator
Name:     sip
Version:  4.19.25
Release:  5%{?dist}
License:  GPLv2 or GPLv3 and (GPLv3+ with exceptions)
Url:      https://riverbankcomputing.com/software/sip/intro
Source0:  https://riverbankcomputing.com/static/Downloads/sip/%{version}/sip-%{version}.tar.gz
Source1:  macros.sip
Source2:  sip-wrapper.sh

Patch3000: sip-4.18-no_strip.patch
Patch3001: sip-4.18-no_rpath.patch
Patch3003: sip-4.19.18-no_hardcode_sip_so.patch
Patch3004: sip-4.19.25-py_ssize_t_clean.patch
Patch3005: sip-4.19.25-pyframe_getback.patch

BuildRequires: make gcc-c++ sed bison flex

Provides:  sip-macros = %{version}-%{release}

%description
SIP is a tool for generating bindings for C++ classes so that they can be accessed as normal Python
classes. SIP takes many of its ideas from SWIG but, because it is specifically designed for C++ and
Python, is able to generate tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has explicit support for the
signal slot mechanism used by the Qt/KDE class libraries. However, SIP can be used to generate
Python bindings for any C++ class library.

%package -n python%{python3_pkgversion}-sip-devel
Summary: Files needed to generate Python bindings for any C++ class library
BuildRequires: python%{python3_pkgversion}-devel
Requires: sip = %{version}-%{release} python%{python3_pkgversion}-devel

%description -n python%{python3_pkgversion}-sip-devel
Files needed to generate Python bindings for any C++ class library

%package -n python%{python3_pkgversion}-pyqt4-sip
Summary: SIP - Python 3/C++ Bindings Generator for pyqt4
BuildRequires: python%{python3_pkgversion}-devel
Provides: python%{python3_pkgversion}-pyqt4-sip-api(%{_sip_api_major}) = %{_sip_api}

%description -n python%{python3_pkgversion}-pyqt4-sip
This is the Python 3 build of pyqt4-SIP.

%package -n python%{python3_pkgversion}-pyqt5-sip
Summary: SIP - Python 3/C++ Bindings Generator for pyqt5
BuildRequires: python%{python3_pkgversion}-devel
Provides: python%{python3_pkgversion}-pyqt5-sip-api(%{_sip_api_major}) = %{_sip_api}

%description -n python%{python3_pkgversion}-pyqt5-sip
This is the Python 3 build of pyqt5-SIP.

%package -n python%{python3_pkgversion}-wx-siplib
Summary: SIP - Python 3/C++ Bindings Generator for wx
BuildRequires: python%{python3_pkgversion}-devel
Provides: python%{python3_pkgversion}-wx-siplib-api(%{_sip_api_major}) = %{_sip_api}

%description -n python%{python3_pkgversion}-wx-siplib
This is the Python 3 build of wx-siplib.

%prep
%autosetup -n %{name}-%{version} -p1

%build
flex --outfile=sipgen/lexer.c sipgen/metasrc/lexer.l
bison --yacc --defines=sipgen/parser.h --output=sipgen/parser.c sipgen/metasrc/parser.y
sed -i -e 's|target = siplib|target = sip|g' siplib/siplib.sbf

mkdir %{_target_platform}-python3-pyqt4
pushd %{_target_platform}-python3-pyqt4
%{__python3} ../configure.py \
  --sip-module=PyQt4.sip \
  -b %{_bindir} -d %{python3_sitearch} -e %{_pyinclude} \
  CXXFLAGS+="%{optflags}" CFLAGS+="%{optflags}" LFLAGS+="%{?__global_ldflags}"

%make_build
popd

mkdir %{_target_platform}-python3-pyqt5
pushd %{_target_platform}-python3-pyqt5
%{__python3} ../configure.py \
  --sip-module=PyQt5.sip \
  -b %{_bindir} -d %{python3_sitearch} -e %{_pyinclude} \
  CXXFLAGS+="%{optflags}" CFLAGS+="%{optflags}" LFLAGS+="%{?__global_ldflags}"

%make_build
popd

sed -i -e 's|target = sip|target = siplib|g' siplib/siplib.sbf
mkdir %{_target_platform}-python3-wx
pushd %{_target_platform}-python3-wx
%{__python3} ../configure.py \
  --sip-module=wx.siplib \
  -b %{_bindir} -d %{python3_sitearch} -e %{_pyinclude} \
  CXXFLAGS+="%{optflags}" CFLAGS+="%{optflags}" LFLAGS+="%{?__global_ldflags}"

%make_build
popd
sed -i -e 's|target = siplib|target = sip|g' siplib/siplib.sbf

%install
%make_install -C %{_target_platform}-python3-pyqt4
%make_install -C %{_target_platform}-python3-pyqt5
%make_install -C %{_target_platform}-python3-wx
mv %{buildroot}%{python3_sitearch}/wx/sip.pyi %{buildroot}%{python3_sitearch}/wx/siplib.pyi
ln -s sip %{buildroot}%{_bindir}/python3-sip

mkdir -p %{buildroot}%{python3_sitearch}/__pycache__/exclude_rpm_hack

install %{SOURCE2} %{buildroot}%{_bindir}/sip-pyqt4
install %{SOURCE2} %{buildroot}%{_bindir}/sip-pyqt5
install %{SOURCE2} %{buildroot}%{_bindir}/sip-wx
sed -i -e 's|@SIP_MODULE@|PyQt4.sip|g' %{buildroot}%{_bindir}/sip-pyqt4
sed -i -e 's|@SIP_MODULE@|PyQt5.sip|g' %{buildroot}%{_bindir}/sip-pyqt5
sed -i -e 's|@SIP_MODULE@|wx.siplib|g' %{buildroot}%{_bindir}/sip-wx

mkdir -p %{buildroot}%{_datadir}/sip

install -D -p -m644 %{SOURCE1} %{buildroot}%{_rpmconfigdir}/macros.d/macros.sip

%files
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%doc README
%{_bindir}/sip
%{_bindir}/sip-pyqt4
%{_bindir}/sip-pyqt5
%{_bindir}/python3-sip
%{_bindir}/sip-wx
%dir %{_datadir}/sip/
%{_rpmconfigdir}/macros.d/macros.sip

%files -n python%{python3_pkgversion}-sip-devel
%{_pyinclude}/sip.h
%{python3_sitearch}/sipconfig.py*
%{python3_sitearch}/sipdistutils.py*
%{python3_sitearch}/__pycache__/*
%exclude %{python3_sitearch}/__pycache__/exclude_rpm_hack

%files -n python%{python3_pkgversion}-pyqt4-sip
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%doc NEWS README
%dir %{python3_sitearch}/PyQt4/
%{python3_sitearch}/PyQt4/sip.*
%{python3_sitearch}/PyQt4_sip-%{version}.dist-info/

%files -n python%{python3_pkgversion}-pyqt5-sip
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%doc NEWS README
%dir %{python3_sitearch}/PyQt5/
%{python3_sitearch}/PyQt5/sip.*
%{python3_sitearch}/PyQt5_sip-%{version}.dist-info/

%files -n python%{python3_pkgversion}-wx-siplib
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%doc NEWS README
%dir %{python3_sitearch}/wx/
%{python3_sitearch}/wx/siplib.*
%{python3_sitearch}/wx_siplib-%{version}.dist-info/

%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.19.25-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.19.25-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.19.25-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.19.25-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Mar 17 2023 Shuo Wang <abushwang@tencent.com> - 4.19.25-1
- initial build
